##################################
 Multimedia Content - SomConnexio
##################################

..
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   !! This file is generated by oca-gen-addon-readme !!
   !! changes will be overwritten.                   !!
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   !! source digest: sha256:1614423d340008335f552b55056ced34554a9187993e584db2ccb85c9738b530
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

.. |badge1| image:: https://img.shields.io/badge/maturity-Beta-yellow.png
   :alt: Beta
   :target: https://odoo-community.org/page/development-status

.. |badge2| image:: https://img.shields.io/badge/licence-AGPL--3-blue.png
   :alt: License: AGPL-3
   :target: http://www.gnu.org/licenses/agpl-3.0-standalone.html

.. |badge3| image:: https://img.shields.io/badge/gitlab-coopdevs%2Fodoo--somconnexio-lightgray.png?logo=gitlab
   :alt: coopdevs/som-connexio/odoo-somconnexio
   :target: https://git.coopdevs.org/coopdevs/som-connexio/odoo-somconnexio

.. |badge4| image:: https://img.shields.io/badge/weblate-Translate%20me-F47D42.png
   :alt: Translate me on Weblate
   :target: https://translation.odoo-community.org/projects/odoo-somconnexio-12-0/odoo-somconnexio-12-0-contract-api-somconnexio

|badge1| |badge2| |badge3| |badge4|

This module supports the Filmin agreement with SomConnexio to offer
Filmin subscriptions as new service included in the SomConnexio catalog.
Filmin subscriptions are offered to SomConnexio members or sponsees
having an active fiber contract with SomConnexio. Limited activated
codes provided by Filmin are assigned to each Filmin Contract.

**Table of contents**

.. contents::
   :local:

***************
 Configuration
***************

No configuration required

*******
 Usage
*******

TODO

**************
 Contributors
**************

-  ``Som Connexió SCCL <https://somconnexio.coop/>``\_\_

   -  Gerard Funonsas gerard.funosas@somconnexio.coop
   -  Borja Gimeno borja.gimeno@somconneixo.coop

-  ``Coopdevs Treball SCCL <https://coopdevs.coop/>``\_\_

   -  Daniel Palomar daniel.palomar@coopdevs.org
   -  Cesar Lopez cesar.lopez@coopdevs.org
